---
title: Community Guidelines
---

## 1. Introduction

Welcome to our community. These guidelines are designed to foster a safe, respectful, and productive environment for all members. While not exhaustive or legally binding, adherence to these principles is strongly encouraged to maintain the integrity and value of our community.

### 1.1. Purpose

The purpose of these Community Guidelines is to:

1. Promote positive interactions and meaningful discussions
1. Protect the well-being and rights of all community members
1. Maintain a welcoming atmosphere for diverse perspectives and backgrounds

### 1.2 Scope

These guidelines apply to all forms of interaction within our community, including but not limited to:

- Forum discussions
- Comment sections
- Direct messaging
- Live events or webinars
- Social media interactions associated with our community

### 1.3 Encouragement to Participate

We highly value your contributions and encourage you to:

1. Actively engage in discussions and share your knowledge
2. Provide constructive feedback and support to fellow members
3. Report any concerns or violations to the community moderators
4. Suggest improvements to enhance the community experience

### 1.4 Code of Conduct

While many aspects of our Community Guidelines are recommendations, our Code of Conduct establishes non-negotiable standards that ALL community members MUST adhere to in ALL interactions within our community spaces.

Nothing in this guide may supercede or overwrite the Code of Conduct.

## 2. Interacting with Staff

Please remember that our staff members generously volunteer their time to help our community remain safe and welcoming. Above all else, be kind to them - moderating online spaces is *hard*, and we don't need to make it harder on them!

### 2.1 Respect for Authority

Our staff team consists of trusted members empowered with tools to maintain community safety and harmony. While they strive for fairness and consistency, it's important to recognize their human nature and the potential for occasional errors.

### 2.2 Dispute Resolution Process

If you believe a staff decision was made in error or in bad faith, we encourage you to follow these steps:

1. Refrain from direct argumentation or confrontation with staff members.
2. Document the incident, including relevant details and any supporting evidence.
3. Submit an appeal through our official [appeal form](/community/appeal).

### 2.3 Appeal Process

- Appeals are reviewed by Naomi, who has exclusive access to the submission form.
- All appeals will be treated confidentially and impartially.
- Information from submissions will only be shared on a need-to-know basis to investigate and resolve the issue.
- Your identity will be protected; any revealed submission information will not be associated with your name.

### 2.4 Staff Accountability

We are committed to maintaining high standards of conduct for our staff. Any substantiated claims of misconduct or abuse of power will be addressed promptly and appropriately.

### 2.5 Continuous Improvement

We value your feedback on our moderation processes. If you have suggestions for improving our systems or policies, please submit them through the appropriate channels.

### 2.6 Responding to Sanctions

If you receive a sanction, here are tips on how to avoid further moderation action:

- Do not continue the behaviour
- Do not attempt to continue the behaviour in a slightly modified way, such as to avoid a specific component of our policies
- Do not make passive-aggressive comments about our policies, staff, or your sanction
- Do not try to justify your behaviour by comparing it to another user's that was not sanctioned
- Do try to learn from the sanction and improve your interactions
- Do keep an open mind and try to learn
- Do be the kindest you can be

## 3. Plural Systems

### 3.1 Understanding Plurality

Plural systems refer to individuals who experience the presence of two or more distinct identities or personality states, often called alters. Our community recognizes and respects the existence of plural systems.

### 3.2 Inclusivity and Respect

1. Plural systems are fully welcome and valued members of our community.
2. We are committed to providing a safe and supportive environment for all system members.
3. Discrimination or harassment based on plurality is strictly prohibited.

### 3.3 Privacy and Boundaries

1. Respect the privacy of plural systems and their individual alters.
2. Do not pressure or attempt to coerce any system or alter to reveal information they are not comfortable sharing.
3. Refrain from trying to identify which alter is fronting or using a platform's plural proxying service.

### 3.4 Self-Disclosure

1. Systems have the right to disclose information about their alters at their own discretion.
2. Members are encouraged to respect the level of disclosure each system or alter chooses.
3. Unsolicited advice or attempts to "help" without consent are not appropriate.

### 3.5 Communication Guidelines

1. Address alters by their preferred names and pronouns when known.
2. If unsure about how to address a system or alter, it's acceptable to politely ask for clarification.
3. Be mindful that switching between alters may result in a difference of communication styles or preferences.

### 3.6 Education and Awareness

1. We encourage community-wide education about plurality to foster understanding and inclusivity.
2. Questions about plurality should be directed to appropriate educational resources rather than to individual systems, unless they have explicitly welcomed such inquiries.

## 4. Tone Tags

### 4.1 Purpose of Tone Tags

In text-based communication, the nuances of tone and intention can often be lost, leading to potential misunderstandings. To address this limitation, we encourage the use of tone tags. These tags provide additional context to messages, helping to clarify the intended tone and reduce misinterpretations.

### 4.2 When to Use Tone Tags

Consider using tone tags in the following situations:

- When your message could be interpreted in multiple ways
- If you're using sarcasm, humour, or other tones that might not be immediately apparent
- When discussing sensitive topics where clarity of intention is crucial
- If you're communicating with someone who has expressed difficulty interpreting tone in text

### 4.3 How to Use Tone Tags

- Place the tone tag at the end of your message or the relevant section
- Use forward slashes to enclose the tag, e.g., `/j` for joking
- You can use multiple tags if needed, e.g., `/s /b` for sarcastic and bitter
- If you're unsure about a tag's meaning, refer to our community glossary or ask for clarification

### 4.4 Commonly Used Tone Tags

| Tag                    | Meaning                              |
| ---------------------- | ------------------------------------ |
| `/aff`                 | Affectionate                         |
| `/apa`                 | Apathetic                            |
| `/b`                   | Bitter                               |
| `/cel`                 | Celebratory                          |
| `/ci`                  | Caring Intent                        |
| `/cj`                  | Coping Joke                          |
| `/co` or `/cf`         | Comforting                           |
| `/ex`                  | Exaggeration                         |
| `/f`                   | fake                                 |
| `/fam`                 | Familial                             |
| `/fex`                 | for example                          |
| `/gen` or `/g`         | Genuine                              |
| `/genq` or `/gq`       | Genuine Question                     |
| `/gens` or `/gs`       | Genuine Suggestion                   |
| `/hj`                  | Half Joking                          |
| `/hyp`                 | Hyperbole                            |
| `/ij`                  | Inside Joke                          |
| `/info`                | Information                          |
| `/j`                   | Joking                               |
| `/jov`                 | Jokingly Overreacting                |
| `/l`, `/ly` or `/lyr`  | Lyrics                               |
| `/lh`                  | Lighthearted                         |
| `/li` or `/lit`        | Literally                            |
| `/lu`                  | Little Upset                         |
| `/m`                   | Metaphorically                       |
| `/md`                  | Melodramatic                         |
| `/nav`                 | Not A Vent                           |
| `/nay`                 | Not At You                           |
| `/nbh`                 | Nobody Here (for vague venting only) |
| `/nbr`                 | Not Being Rude                       |
| `/nc` or `/neg`        | Negative connotation                 |
| `/ncm`                 | Not Comparing                        |
| `/neu`                 | Neutral connotation                  |
| `/nf`                  | Not Forced                           |
| `/nm`                  | Not Mad (or upset)                   |
| `/np`                  | No Pressure                          |
| `/npa`                 | Not Passive Aggressive               |
| `/nsx` or `/nx`        | Non Sexual Intent                    |
| `/ny`                  | Not Yelling                          |
| `/op`                  | Optional                             |
| `/ot`                  | Off Topic                            |
| `/p` or `/plat`        | Platonic                             |
| `/pc` or `/pos`        | Positive connotation                 |
| `/q`                   | Quote                                |
| `/ref`                 | Reference                            |
| `/rh`, `/rt` or `/rhq` | Rhetorical Question                  |
| `/s` or `/sar`         | Sarcastic                            |
| `/srs`                 | Serious                              |
| `/sym`                 | Sympathetic                          |
| `/t`                   | Teasing                              |
| `/tc`, `/ti` or `/tic` | Typing a tic                         |

### 4.5 Respecting Tone Tags

- When someone uses a tone tag, interpret their message accordingly
- If you're unsure about the meaning of a tag, ask politely for clarification
- Do not mock or belittle others for using tone tags

### 4.6 Accessibility Considerations

- Tone tags can be particularly helpful for neurodivergent individuals who may have difficulty interpreting tone in text
- Screen readers can often interpret tone tags, making them a useful tool for visually impaired users

### 4.7 Limitations of Tone Tags

- While helpful, tone tags are not a perfect solution and may not convey all nuances of communication
- They should be used as a supplement to clear writing, not a replacement for it

### 4.8 Community-Specific Tags

- Our community may develop additional tags specific to our discussions
- New tags will be added to our glossary after community consensus

## 5. Pronouns

### 5.1 Importance of Pronouns

Pronouns are an essential aspect of personal identity and respectful communication. Our community values and respects each individual's right to self-identify and be addressed correctly.

### 5.2 Displaying Pronouns

We strongly encourage all community members to display their pronouns:

- In your platform bio
- Using designated pronoun roles in our Discord community, or comparable feature on other platforms
- As part of your username or display name, if desired

### 5.3 Benefits of Sharing Pronouns

1. Clarity: Helps others address you correctly
2. Inclusivity: Creates a welcoming environment for all gender identities
3. Normalization: Reduces stigma around pronoun sharing
4. Education: Raises awareness about gender diversity

### 5.4 Normalizing Pronoun Sharing

By encouraging all members to share pronouns, regardless of gender identity or expression, we:

- Challenge the assumption that only transgender individuals share pronouns
- Create a safer space for transgender and non-binary individuals to share their pronouns without implicitly outing themselves
- Promote a culture of respect and understanding

### 5.5 Respecting Others' Pronouns

- Always use the pronouns a person has specified for themselves
- If you're unsure about someone's pronouns, it's appropriate to politely ask
- If you make a mistake, apologize briefly, correct yourself, and move on

### 5.6 Pronoun Options

While not exhaustive, common pronoun options include:

- She/her/hers
- He/him/his
- They/them/theirs
<!-- cSpell:disable-next-line -->
- Neopronouns (e.g., xe/xem/xyr, ze/zir/zirs)
- Any pronouns
- No pronouns (use name only)

### 5.7 Changing Pronouns

- Members are welcome to update their pronouns at any time
- Respect and use a person's current pronouns, even if you knew them by different pronouns previously

### 5.8 Pronoun Misuse

- Intentional misuse of pronouns (misgendering) is a form of harassment and violates our community guidelines
- Repeated accidental misuse, despite correction, may be addressed by moderation

### 5.9 Privacy Considerations

- While we encourage pronoun sharing, it is ultimately a personal choice
- Do not pressure others to share their pronouns if they are not comfortable doing so

## 6. Accessibility

Our community is committed to ensuring that all members, regardless of their needs, can fully participate and engage with our content. We encourage everyone to follow these accessibility guidelines to create a more inclusive environment.

### 6.1 Alt Text for Images

Alt text (alternative text) provides a textual description of images for those who use screen readers or cannot view images.

- Always include alt text when posting images.
- Describe the key elements of the image concisely.
- If the image contains text, include that text in the alt description.
  Example: Instead of alt="meme", use alt="A cat wearing sunglasses with the text 'Deal with it' below"

### 6.2 Creating Accessible Content

#### 6.2.1 Descriptive Link Text

- Use descriptive link text that indicates where the link leads.
- Avoid using "click here" or "read more" as standalone link text.

Example: Instead of "Click here to read about our events", use "View our upcoming community events"

#### 6.2.2 Avoiding Flashing Content

- Do not post content that flashes more than three times per second.
- If you must share such content, provide a clear warning beforehand.

#### 6.2.3 Structuring Content

- Use headings to organize content hierarchically (H1, H2, H3, etc.).
- Break long paragraphs into shorter, more digestible sections.
- Use bullet points or numbered lists for easy scanning.

#### 6.2.4 Multimedia Content

- Provide captions for videos.
- Offer transcripts for audio content when possible.

### 6.3 Continuous Improvement

- We welcome feedback on how to improve our community's accessibility.
- Report any accessibility issues to the moderation team.

## 7. Content and Trigger Warnings

Our community is committed to creating a safe and respectful environment for all members. Content and trigger warnings play a crucial role in this effort by allowing individuals to make informed decisions about engaging with potentially distressing content.

### 7.1 Purpose of Content/Trigger Warnings

- To give members advance notice of potentially sensitive or disturbing content
- To allow individuals to prepare themselves emotionally or choose to avoid the content
- To promote a culture of empathy and consideration within our community

### 7.2 When to Use Warnings

:::caution[Warning!]
Content/Trigger warnings are **mandatory** in all of our community spaces. Repeated patterns of failure to properly label your content will result in sanctions. "I forgot" is not an acceptable excuse.
:::

Use content or trigger warnings when posting about:

- Graphic violence or gore
- Sexual content or explicit discussions of sexuality (except within our clearly-indicated adult-only areas)
- Abuse (physical, emotional, sexual)
- Self-harm or suicide
- Eating disorders or body image issues
- Substance abuse or addiction
- Mental health issues
- Phobias (e.g., spiders, heights, confined spaces)
- Political extremism or hate speech
- Natural disasters or traumatic events
- Flashing images or loud noises (for photosensitive epilepsy)

Remember, this list is not exhaustive. If you're unsure whether content needs a warning, err on the side of caution and provide one.

### 7.3 How to Use Content/Trigger Warnings

- Place the warning at the beginning of your post or message
- Use clear, specific language
- If possible, use spoiler tags or a "read more" cut to hide the sensitive content

Example formats:

"CW: Discussion of eating disorders"
"TW: Graphic description of violence"
"Content Warning: This post contains references to suicide"

### 7.4 Respecting Warnings

- Do not mock or belittle others for using or needing content warnings
- If someone asks for a warning on a specific topic, respect their request in future interactions

### 7.5 False Alarms and Overuse

While we encourage the use of content warnings, try to avoid overuse for mundane topics. This helps maintain their effectiveness for truly sensitive content.

### 7.6 Moderator Intervention

Moderators may add content warnings to posts if they deem it necessary. Repeated failure to use appropriate warnings may result in moderation action.

## 8. Conflict Resolution

Disagreements and conflicts can arise in any community. Our goal is to foster an environment where conflicts can be resolved respectfully and constructively. This section outlines the steps for resolving conflicts and when to involve moderators.

### 8.1 General Principles

- Treat all parties with respect, even in disagreement
- Assume good faith unless proven otherwise
- Focus on the issue, not personal attacks
- Be open to different perspectives and willing to compromise

### 8.2 Steps for Resolving Conflicts

#### 8.2.1 Direct Communication

- If you have an issue with another member, try to address it directly with them first.
- Use private messages to avoid public confrontations.
- Clearly and calmly explain your concerns, using "I" statements.
- Listen to their perspective without interrupting.
- Look for common ground and potential solutions.

#### 8.2.2 Cool-Down Period

If emotions are running high:

- Take a break from the discussion.
- Reflect on the issue and your role in the conflict.
- Return to the conversation when you can discuss it calmly.

#### 8.2.3 Seeking Mediation

If direct communication doesn't resolve the issue:

- Ask a neutral third party from the community to mediate.
- Both parties should agree on the mediator.
- The mediator should facilitate discussion, not take sides.

### 8.3 When to Involve Moderators

Involve moderators if:

- The conflict violates our Code of Conduct
- You feel unsafe or harassed
- The conflict is disrupting the broader community
- Previous attempts at resolution have failed
- You're unsure how to handle the situation

### 8.4 How to Involve Moderators

- Use the designated reporting system on the platform.
- Provide a clear, factual account of the issue.
- Include relevant screenshots or links if applicable.
- Explain steps you've already taken to resolve the conflict.

### 8.5 Moderator Actions

Moderators may:

- Facilitate discussion between parties
- Issue warnings or reminders about community guidelines
- Temporarily mute or suspend accounts
- Remove inflammatory content
- In severe cases, ban members who consistently create conflicts

### 8.6 Appealing Moderator Decisions

If you disagree with a moderator's decision:

- Wait 24 hours to ensure you can discuss it calmly
- Contact the moderation team through the appropriate channels
- Clearly explain why you think the decision should be reconsidered
- Be prepared to provide additional context or evidence

### 8.7 Conflict Prevention

To minimize conflicts:

- Re-read your posts before sending to ensure they're not unintentionally inflammatory
- Use tone indicators when your intent might be unclear
- Ask for clarification before assuming negative intent
- Be willing to apologize and correct mistakes

### 8.8 Learning from Conflicts

After a conflict is resolved:

- Reflect on what led to the disagreement
- Consider how it could have been prevented or handled better
- Apply these lessons in future interactions

## 9. This Should Be Fun!

It is important to remember that engaging with our community should be a fun process. If you aren't enjoying your time, please consider some of these options:

### 9.1. Take a Break

It's okay if you need some time away from our community! We'll be here when you get back, so don't hesitate to step away for a while and decompress. Let yourself come back refreshed so you have the best experience possible.

### 9.2. Evaluate Your Engagement

Our community spaces are intended to be fun, relaxed, and wholesome environments. If you find that you aren't meshing with our vibe in the way that you want, consider taking a look at the type of interactions you are creating. It may be that you aren't using our community in the best way.

### 9.3. Temporary Bans

If you need a break and you find yourself unable to step away, or you keep coming back to check on things when you really do not want to, please reach out to our staff. We are more than willing to issue temporary bans to help you preserve the space you need.

## 10. Mini-modding

"Mini-modding" is a term often used to describe behaviour in which a non-staff user instructs another user to amend their behaviour as if they were a member of staff.

Our community does not prohibit mini-modding, provided:

- You gently encourage and support members in properly integrating with our community
- You do not represent yourself as a member of NHCarrigan's team
- You do not belittle, call out, or antagonise a user who is violating our policies

Remember that the best way to correct someone's behaviour is to lead by example. If that fails, do not escalate - instead, report the behaviour to our team.
