---
title: Staff Handbook
---

Welcome to our organization. This Staff Handbook serves as a comprehensive guide to our policies, procedures, and expectations. It is designed to help you understand your role in our community and how you can contribute to our collective success.

We rely on every staff member, regardless of position, to help keep our community running smoothly and efficiently. Your dedication, skills, and adherence to our standards are crucial in achieving our organizational goals.

By familiarizing yourself with this handbook and adhering to its guidelines, you play a vital role in maintaining the integrity and effectiveness of our organization. Your commitment to these principles helps ensure a positive, productive, and harmonious work environment for all.

## 1. Activity Requirements

### 1.1 Flexible Engagement

We recognize and deeply appreciate that our staff members are volunteers dedicating their time and effort to support our community. As such, we do not impose rigid activity quotas or specific engagement levels.

### 1.2 Communication of Extended Absences

While we maintain a flexible approach to activity, we kindly request that you inform us of any anticipated absences:

- For absences exceeding one week, please notify the team via the `#staff-chat` channel on Discord.
- This communication helps us manage workload distribution and ensures continued smooth operation of our community.

### 1.3 Extended Inactivity

In cases of prolonged inactivity:

- If you are inactive for more than one month without prior communication, we may remove you from the active staff team.
- This policy helps maintain an engaged and responsive staff roster.
- Please note that removal due to inactivity is not punitive and does not reflect negatively on your contributions.

### 1.4 Returning to the Team

We value your contributions and understand that life circumstances can change:

- If you've been removed due to inactivity, you are always welcome to rejoin the staff team when your schedule permits.
- To rejoin, please contact an admin.

### 1.5 Balancing Commitments

We encourage you to balance your volunteer work with your personal life and other commitments:

- Your well-being is important to us. Never feel pressured to overextend yourself.
- If you find your role becoming stressful or overly time-consuming, please discuss this with an admin.

### 1.6 Recognition of Contributions

While we don't set specific activity requirements, we do recognize and appreciate consistent engagement and contributions:

- Regular participation helps build a strong, cohesive community.
- Outstanding contributions may be acknowledged through our staff recognition program.

## 2. Moderator Guidelines

### 2.1 Role Definition

As a moderator, you occupy a position of trust within our community. This role comes with additional responsibilities and tools to ensure the safety and well-being of our community members. However, it's crucial to understand that:

- Being a moderator does not elevate you above other community members.
- Your role is one of service and support, not authority or superiority.

### 2.2 General Expectations

#### 2.2.1 Leading by Example

As moderators, you are expected to exemplify the ideal community member:

- Be active and engaged within the community.
- Strictly adhere to all community rules and guidelines.
- Demonstrate a welcoming and inclusive attitude towards all members, especially newcomers.

#### 2.2.2 Balancing Roles

Remember that you are both a moderator and a community member:

- Not every interaction requires a moderation action.
- Engage in regular social interactions with fellow community members.
- Maintain a balance between your moderator duties and personal enjoyment within the community.

#### 2.2.3 Platform Familiarity

Our community spans multiple platforms:

- You are entrusted with maintaining all our platforms, but you're not expected to be an expert on all of them.
- Focus on moderating platforms you're comfortable with.
- Seek assistance or guidance from fellow moderators when dealing with unfamiliar platforms.

### 2.3 Conduct Guidelines

#### 2.3.1 Professionalism

Maintain a professional demeanour in all interactions:

- Remain calm and objective, especially in challenging situations.
- Avoid engaging in or escalating conflicts.
- Use appropriate language and tone at all times.

#### 2.3.2 Fairness and Consistency

Apply rules and take actions consistently:

- Treat all community members equally, regardless of their status or your personal feelings.
- Make decisions based on community guidelines, not personal preferences.

#### 2.3.3 Transparency

Be open about your actions as a moderator:

- Clearly explain the reasons for any moderation decisions when appropriate.
- Be willing to discuss your actions with other moderators or admins if questions arise.

### 2.4 Collaboration and Support

#### 2.4.1 Team Communication

Maintain open lines of communication with your fellow moderators:

- Use designated channels (e.g., `#staff-chat`) to discuss moderation issues.
- Share experiences and seek advice when facing challenging situations.

#### 2.4.2 Continuous Learning

Stay informed and improve your moderation skills:

- Keep up-to-date with any changes to community guidelines or moderation policies.
- Participate in any provided training or skill-sharing sessions.

#### 2.4.3 Escalation Protocol

Know when and how to escalate issues:

- Identify situations that require input from administrators.
- Follow established procedures for escalating complex or sensitive matters.

### 2.5 Sanction Logging

All moderation actions you take must be logged via our [web form](https://moderation.nhcarrigan.com/log).

If you have not been granted a token, please notify Naomi and she will generate one for you.

## 3. Working With Fellow Moderators

### 3.1 Communication Channels

#### 3.1.1 Primary Communication Platform
- Our forum as our primary communication hub for the moderation team.
- A private `staff` category is available for internal discussions.

#### 3.1.2 Use of Staff Chat
- Utilize the `staff` channel for:
  - Discussing concerns
  - Seeking advice on handling situations
  - Requesting assistance with ongoing issues
  - Sharing relevant information with the team

### 3.2 Collaborative Problem-Solving

- Approach fellow moderators for help and insights when needed.
- Be open to offering assistance when others request it.
- Engage in constructive discussions to find optimal solutions.

### 3.3 Team Unity and Public Image

- Maintain a united front in public spaces.
- Avoid disagreeing with or criticizing fellow moderators in public forums.
- If you have concerns about a moderation action or a colleague's behavior:
  - Address the issue privately in the staff chat or through direct messages.
  - Seek resolution through open and respectful dialogue.

### 3.4 Conflict Resolution

- If unable to resolve disagreements among yourselves:
  - Escalate the matter to Naomi for guidance.
  - Present the situation objectively, providing necessary context.

### 3.5 Supporting Each Other

- Recognize that moderation can be challenging.
- Offer emotional support and encouragement to fellow moderators.
- Share experiences and coping strategies for dealing with difficult situations.

### 3.6 Knowledge Sharing

- Use the staff chat to share useful resources, tools, or techniques.
- Discuss emerging trends or patterns in user behavior that may require attention.

### 3.7 Consistency in Moderation

- Regularly discuss and align on interpretation and enforcement of community rules.
- Share examples of how you've handled specific situations to ensure consistency.

### 3.8 Respecting Privacy

- Keep all discussions in staff channels confidential.
- Do not share private moderator conversations with community members.

### 3.9 Active Participation

- Regularly check and engage in staff communications.
- Contribute to team discussions and decision-making processes.

### 3.10 Continuous Improvement

- Be open to feedback from fellow moderators.
- Suggest improvements to moderation processes or team communication.
- Participate in any team training or development activities.

## 4. User Support

### 4.1 Role in User Experience

As a member of our team, you play a crucial role in ensuring a positive and smooth user experience across all our platforms. Your ability to provide timely and accurate support is essential to our community's satisfaction and growth.

### 4.2 Knowledge Base

- Familiarize yourself with most of our projects to answer a wide range of questions.
- Stay updated on recent changes or updates to our projects.
- Utilize available resources (documentation, FAQs, wikis) to assist users effectively.

### 4.3 Handling User Inquiries

#### 4.3.1 Immediate Assistance
- Respond promptly to users seeking help on any of our platforms.
- Provide clear, concise answers to questions you're confident about.

#### 4.3.2 Complex Inquiries
- For questions you're unsure about, don't hesitate to seek help.
- Inform the user that you're looking into their issue to manage expectations.

### 4.4 Collaborative Problem-Solving

- Utilize the staff chat in Discord for discussing complex user questions.
- Engage with fellow staff members to collaboratively find solutions.
- Share knowledge and insights to improve the team's overall support capabilities.

### 4.5 Follow-up

- After providing a solution, check if the user's issue has been fully resolved.
- Encourage users to reach out again if they need further assistance.

### 4.6 Continuous Improvement

- Keep track of common user issues and suggest improvements to our documentation or user interfaces.
- Share insights gained from user interactions with the rest of the team to enhance our overall support quality.

## 5. Contributor Support

### 5.1 Welcoming New Contributors

- Greet new contributors warmly when they show interest in our projects.
- Provide guidance on where to find our contribution guidelines and code of conduct.
- Offer assistance in identifying suitable first issues or tasks for newcomers.

### 5.2 Technical Assistance

- Help contributors set up their development environments.
- Provide explanations or resources for understanding our project structure and coding standards.
- Assist with version control (e.g. git) usage if needed.

### 5.3 Code Review Support

- Offer constructive feedback on pull requests or proposed changes.
- Explain the reasoning behind any requested modifications.
- Guide contributors through the process of updating their submissions.

### 5.4 Documentation Support

- Assist contributors in locating or updating project documentation.
- Encourage and guide contributors who wish to improve our documentation.
- Provide feedback on proposed documentation changes.

### 5.5 Issue Clarification

- Help contributors understand the scope and requirements of open issues.
- Provide additional context or clarification on feature requests or bug reports.

### 5.6 Communication Channels

- Direct contributors to appropriate communication channels (e.g., mailing lists, chat rooms, forums) for project-specific discussions.
- Monitor these channels to provide timely responses to contributor queries.

### 5.7 Mentoring

- Offer mentorship to promising contributors who show consistent interest.
- Provide guidance on best practices, advanced topics, and project goals.

### 5.8 Recognition and Encouragement

- Acknowledge and thank contributors for their efforts, regardless of the outcome.
- Highlight significant contributions in project updates or community announcements.

### 5.9 Conflict Resolution

- Mediate any disagreements between contributors professionally and impartially.
- Ensure discussions remain constructive and aligned with our code of conduct.

### 5.10 Continuous Improvement

- Regularly review and update our contribution processes based on feedback.
- Seek input from contributors on how to improve their experience.

## 6. Cross-Platform Access

### 6.1 Eligibility for Cross-Platform Roles

- Once you have been selected for a staff position on any of our platforms, you become eligible to request staff access on additional platforms.
- This opportunity is open to all current staff members in good standing.

### 6.2 Requesting Additional Platform Access

- If you wish to expand your staff role to other platforms:
  - Express your interest to an admin or through the designated channel for such requests.
  - Specify which additional platform(s) you'd like to moderate.
  - Briefly explain why you're interested in moderating these additional platforms.

### 6.3 Approval Process

- Requests for additional platform access will be reviewed by the admin team.
- Factors considered in the approval process may include:
  - Your performance in your current role
  - Your familiarity with the requested platform
  - The current staffing needs on that platform

### 6.4 Training and Onboarding

- If approved for a cross-platform role, you may be required to undergo platform-specific training.
- Familiarize yourself with any unique rules or moderation tools for the new platform.

### 6.5 Responsibilities of Cross-Platform Staff

- Maintain consistency in rule enforcement across all platforms you moderate.
- Be aware of platform-specific nuances and adjust your approach accordingly.
- Help bridge communication between different platform teams.

### 6.6 Benefits of Cross-Platform Moderation

- Provides a more cohesive user experience across our community's various platforms.
- Allows for more efficient sharing of information and moderation strategies.
- Enhances your skills and versatility as a moderator.

### 6.7 Balancing Responsibilities

- Ensure that taking on additional platforms does not negatively impact your performance on your original platform.
- Communicate with the moderation team if you feel overwhelmed or need to scale back your responsibilities.

### 6.8 Periodic Review

- Your cross-platform roles will be periodically reviewed to ensure effective moderation across all assigned platforms.
- Feedback and additional training may be provided as needed.
